@@ -22,7 +22,6 @@ use Zend\Mvc\Application;
 use Zend\Mvc\Exception\RuntimeException;
 use Zend\Mvc\MvcEvent;
 use Zend\ServiceManager\Exception\ServiceNotFoundException;
-use Zend\ServiceManager\ServiceManager;
 use Zend\Stdlib\ResponseInterface as Response;
 use Zend\Stdlib\StringUtils;
 use Zend\Text\Table;
@@ -128,7 +127,7 @@ class RouteNotFoundStrategy extends AbstractListenerAggregate
         $mm = null;
         try{
             $mm = $sm->get('ModuleManager');
-        } catch (ServiceNotFoundException $e) {
+        } catch (ServiceNotFoundException $exception) {
             // The application does not have or use module manager, so we cannot use it
         }
 
@@ -138,19 +137,11 @@ class RouteNotFoundStrategy extends AbstractListenerAggregate
             if (!$console instanceof ConsoleAdapter) {
                 throw new ServiceNotFoundException();
             }
-        } catch (ServiceNotFoundException $e) {
+        } catch (ServiceNotFoundException $exception) {
             // The application does not have console adapter
             throw new RuntimeException('Cannot access Console adapter - is it defined in ServiceManager?');
         }
 
-        // Try to fetch router
-        $router = null;
-        try{
-            $router = $sm->get('Router');
-        } catch (ServiceNotFoundException $e) {
-            // The application does not have a router
-        }
-
         // Retrieve the script's name (entry point)
         $scriptName = '';
         if ($request instanceof ConsoleRequest) {
